@@ -1,5 +1,5 @@
-from numpy import zeros, array, dot, delete, append, unique
-from numpy import sin, arccos, arctan2
+from numpy import zeros, array, linspace, delete, append, unique
+from numpy import dot, sin, arccos, arctan2
 from numpy.linalg import norm
 
 # Funciones para generar Mesh
@@ -12,19 +12,16 @@ def LinearMesh(L,Ne,x0=0):
             Ne:     Número de elementos a crear.
             x0:     Posición del primer nodo.
     '''
-    L_element=L/Ne
     # Crea arreglo de nodos
-    nodos = zeros(Ne+1)
-    for i in range(Ne+1): 
-        nodos[i]=x0 + i*L_element
+    x = linspace(x0,x0+L,Ne+1)
     # Crea arreglo de conexiones
-    conex = zeros((Ne,2),'int')
-    conex[:,0],conex[:,1] = range(Ne), range(1,Ne+1)
+    cnx = zeros((Ne,2),'int')
+    cnx[:,0],cnx[:,1] = range(Ne), range(1,Ne+1)
     class Mesh:
-        NN = len(nodos)
-        Nodos = nodos
-        NC = len(conex)
-        Conex = conex
+        NN = len(x)
+        Nodos = x
+        NC = len(cnx)
+        Conex = cnx
     return Mesh
 
 def founMesh(Lx1,Ly1,Lx2,Ly2,mz1):
@@ -49,7 +46,7 @@ def founMesh(Lx1,Ly1,Lx2,Ly2,mz1):
 
 def load_obj(fileName):
     '''
-    Función que lee archivos tipo obj de blender para generar crear arreglos\
+    Función que lee archivos tipo obj para generar crear arreglos\
     de coordenadas, elementos triangulares y rectangules (tri, quad).
     '''
     vertices, tri, quad = [], [], []
@@ -71,6 +68,83 @@ def load_obj(fileName):
 
     return vertices, tri, quad
 
+def GenBrickMesh_3D(L, B, H, lc):
+    '''Crea la malla de un elemento rectangular con códigos programados en Python.
+
+    L  : Longitud o base del elemento  en metros
+    H  : Altura del elemento en metros
+    lc : Número de elementos en la dirección más corta entre L o H.
+    '''
+    # Lectura del archivo data
+    # Define la cantidad de elementos y sus dimensiones en ambas direcciones.
+
+    if min((L, B, H)) == L:
+        nx = lc
+        ms_x = L / nx
+        ny = round(B / ms_x)
+        ms_y = B / ny
+        nz = round(H / ms_x)
+        ms_z = H / nz
+
+    elif min((L, B, H)) == B:
+        ny = lc
+        ms_y = B / ny
+        nx = round(L / ms_y)
+        ms_x = L / nx
+        nz = round(H / ms_y)
+        ms_z = H / nz
+
+    else:
+        nz = lc
+        ms_z = H / nz
+        ny = round(B / ms_z)
+        ms_y = B / ny
+        nx = round(L / ms_z)
+        ms_x = L / nx
+
+    # Imprime los resultados
+    print('=' * 16 + 'Mesh' + '=' * 16)
+    print("nx = {}, dx = {:.2f}, ny = {}, dy = {:.2f}, nz = {}, dz = {:.2f}".
+          format(nx, ms_x, ny, ms_y, nz, ms_z))
+
+    # Define los nodos de la malla
+    noNodes = (nx + 1) * (ny + 1) * (nz + 1)
+    Nodes = zeros((noNodes, 3),'float64')
+
+    ni = 0
+    for i in range(nz + 1):
+        for j in range(ny + 1):
+            for k in range(nx + 1):
+                Nodes[ni] = (ms_x * k, ms_y * j, ms_z * i)
+                ni = ni + 1
+
+    # Se establecen las conexiones entre los nodos de la malla para definir los elementos finitos
+    noElem = nx * ny * nz
+    connect = zeros((noElem, 8), 'int')
+
+    cont = 0
+    for k in range(0, nz):
+        for i in range(0, ny):
+            for j in range(0, nx):
+
+                connect[cont, 0] = j + (i * (nx + 1)) + (k * (nx + 1) * (ny + 1))
+                connect[cont, 1] = j + (i * (nx + 1)) + (k * (nx + 1) * (ny + 1)) + 1
+                connect[cont, 2] = j + ((i + 1) * (nx + 1)) + ((k) * (nx + 1) * (ny + 1)) + 1
+                connect[cont, 3] = j + ((i + 1) * (nx + 1)) + ((k) * (nx + 1) * (ny + 1))
+                connect[cont, 4] = j + (i * (nx + 1)) + ((k + 1) * (nx + 1) * (ny + 1))
+                connect[cont, 5] = j + (i * (nx + 1)) + ((k + 1) * (nx + 1) * (ny + 1)) + 1
+                connect[cont, 6] = j + ((i + 1) * (nx + 1)) + ((k + 1) * (nx + 1) * (ny + 1)) + 1
+                connect[cont, 7] = j + ((i + 1) * (nx + 1)) + ((k + 1) * (nx + 1) * (ny + 1))
+                cont += 1
+
+    # Se agrega los parámetros calculados al diccionario Data
+    class Mesh:
+        NN = noNodes
+        Nodos = Nodes
+        NC = noElem
+        Conex = connect
+
+    return Mesh
 
 # Fuciones para crear condiciones de borde
 def BC_2Dx(X,dy,x,tipo,gdl,val):
